package com.zhentao.controller;

import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.IncorrectCredentialsException;
import org.apache.shiro.authc.UnknownAccountException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;

@Controller
public class LoginController {

    // ---------------------- 登录页面 ----------------------
    @GetMapping("/login")
    public String loginPage() {
        return "login"; // 对应 resources/templates/login.html
    }

    // ---------------------- 登录处理 ----------------------
    @PostMapping("/login")
    public String login(String username, String password, Model model) {
        Subject subject = SecurityUtils.getSubject();
        UsernamePasswordToken token = new UsernamePasswordToken(username, password);
        try {
            subject.login(token); // 执行认证
            return "redirect:/home"; // 认证成功跳转主页
        } catch (UnknownAccountException e) {
            model.addAttribute("error", "用户名不存在");
        } catch (IncorrectCredentialsException e) {
            model.addAttribute("error", "密码错误");
        }
        return "login"; // 认证失败返回登录页
    }

    // ---------------------- 主页（需认证） ----------------------
    @GetMapping("/home")
    public String homePage(Model model) {
        Subject subject = SecurityUtils.getSubject();
        model.addAttribute("username", subject.getPrincipal());
        return "home"; // 对应 resources/templates/home.html
    }

    // ---------------------- 未授权页面 ----------------------
    @GetMapping("/unauthorized")
    public String unauthorizedPage() {
        return "unauthorized"; // 对应 resources/templates/unauthorized.html
    }

    // ---------------------- 退出登录 ----------------------
    @GetMapping("/logout")
    public String logout() {
        SecurityUtils.getSubject().logout();
        return "redirect:/login";
    }
}